internal function
coda_glmnet_longitudinal0(
x,
lrX,
idlrX,
nameslrX,
y,
x_time,
subject_id,
ini_time,
end_time,
covar = NULL,
ktop = NULL,
lambda = "lambda.1se",
alpha = 0.9,
nfolds = 10
).
abundance matrix or data frame in long format (several rows per individual)
log-ratio matrix
indices table in the log-ratio matrix
colnames of the log-ratio matrix
outcome (binary); data type: numeric, character or factor vector
observation times
subject id
initial time to be analyzed
end time to be analyzed
data frame with covariates (default = NULL)
given number of selected taxa or compute the best number in case it is NULL (default = NULL)
penalization parameter (default = "lambda.1se")
elastic net parameter (default = 0.9)
number of folds
M. Calle - T. Susin