Learn R Programming

coda4microbiome (version 0.2.4)

impute_zeros: impute_zeros

Description

Simple imputation: When the abundance table contains zeros, a positive value is added to all the values in the table. It adds 1 when the minimum of table is larger than 1 (i.e. tables of counts) or it adds half of the minimum value of the table, otherwise.

Usage

impute_zeros(x)

Value

x abundance matrix or data frame with zeros substituted by imputed positive values

Arguments

x

abundance matrix or data frame (rows are samples, columns are variables (taxa))

Author

M. Calle - T. Susin

Examples

Run this code

data(HIV, package = "coda4microbiome")

x<-impute_zeros(x_HIV)

Run the code above in your browser using DataLab